Module accounts_api

Module accounts_api 

Enums

GetAccountError
struct for typed errors of method get_account
ListAccountBalancesError
struct for typed errors of method list_account_balances
ListAccountsError
struct for typed errors of method list_accounts

Functions

get_account
Retrieve a Seller Wallet bank account by Amazon account identifier.
list_account_balances
Retrieve the balance in a given Seller Wallet bank account.
list_accounts
Get Seller Wallet accounts for a seller.