Module aplus_content_api

Module aplus_content_api 

Enums

CreateContentDocumentError
struct for typed errors of method create_content_document
GetContentDocumentError
struct for typed errors of method get_content_document
ListContentDocumentAsinRelationsError
struct for typed errors of method list_content_document_asin_relations
PostContentDocumentApprovalSubmissionError
struct for typed errors of method post_content_document_approval_submission
PostContentDocumentAsinRelationsError
struct for typed errors of method post_content_document_asin_relations
PostContentDocumentSuspendSubmissionError
struct for typed errors of method post_content_document_suspend_submission
SearchContentDocumentsError
struct for typed errors of method search_content_documents
SearchContentPublishRecordsError
struct for typed errors of method search_content_publish_records
UpdateContentDocumentError
struct for typed errors of method update_content_document
ValidateContentDocumentAsinRelationsError
struct for typed errors of method validate_content_document_asin_relations

Functions

create_content_document
Creates a new A+ Content document. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
get_content_document
Returns an A+ Content document, if available. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
list_content_document_asin_relations
Returns a list of ASINs that are related to the specified A+ Content document, if available. If you don’t include the asinSet parameter, this operation returns all ASINs related to the content document. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
post_content_document_approval_submission
Submits an A+ Content document for review, approval, and publishing. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
post_content_document_asin_relations
Replaces all ASINs related to the specified A+ Content document, if available. This operation can add or remove ASINs, depending on the current set of related ASINs. Removing an ASIN will suspend the content document from that ASIN. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
post_content_document_suspend_submission
Submits a request to suspend visible A+ Content. This doesn’t delete the content document or the ASIN relations. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
search_content_documents
Returns a list of all A+ Content documents, including metadata, that are assigned to a selling partner. To get the actual contents of the A+ Content documents, call the getContentDocument operation. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
search_content_publish_records
Searches for A+ Content publishing records, if available. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
update_content_document
Updates an existing A+ Content document. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
validate_content_document_asin_relations
Checks if the A+ Content document is valid for use on a set of ASINs. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.