Module awd_api

Enums

CancelInboundError
struct for typed errors of method cancel_inbound
CheckInboundEligibilityError
struct for typed errors of method check_inbound_eligibility
ConfirmInboundError
struct for typed errors of method confirm_inbound
CreateInboundError
struct for typed errors of method create_inbound
GetInboundError
struct for typed errors of method get_inbound
GetInboundShipmentError
struct for typed errors of method get_inbound_shipment
GetInboundShipmentLabelsError
struct for typed errors of method get_inbound_shipment_labels
ListInboundShipmentsError
struct for typed errors of method list_inbound_shipments
ListInventoryError
struct for typed errors of method list_inventory
UpdateInboundError
struct for typed errors of method update_inbound
UpdateInboundShipmentTransportDetailsError
struct for typed errors of method update_inbound_shipment_transport_details

Functions

cancel_inbound
Cancels an AWD Inbound order and its associated shipment. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The preceding table indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
check_inbound_eligibility
Determines if the packages you specify are eligible for an AWD inbound order and contains error details for ineligible packages. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The preceding table indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
confirm_inbound
Confirms an AWD inbound order in DRAFT status. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
create_inbound
Creates a draft AWD inbound order with a list of packages for inbound shipment. The operation creates one shipment per order. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The preceding table indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
get_inbound
Retrieves an AWD inbound order. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 2 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The preceding table indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
get_inbound_shipment
Retrieves an AWD inbound shipment. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 2 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API
get_inbound_shipment_labels
Retrieves the box labels for a shipment ID that you specify. This is an asynchronous operation. If the label status is GENERATED, then the label URL is available. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 2 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The preceding table indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
list_inbound_shipments
Retrieves a summary of all the inbound AWD shipments associated with a merchant, with the ability to apply optional filters. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
list_inventory
Lists AWD inventory associated with a merchant with the ability to apply optional filters. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 2 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
update_inbound
Updates an AWD inbound order that is in DRAFT status and not yet confirmed. Use this operation to update the packagesToInbound, originAddress and preferences attributes. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The preceding table indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
update_inbound_shipment_transport_details
Updates transport details for an AWD shipment. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.