create_inbound

Function create_inbound 

pub async fn create_inbound(
    configuration: &Configuration,
    body: InboundOrderCreationData,
) -> Result<InboundOrderReference, Error<CreateInboundError>>
Creates a draft AWD inbound order with a list of packages for inbound shipment. The operation creates one shipment per order. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The preceding table indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.