Module customer_feedback_api

Enums

GetBrowseNodeReturnTopicsError
struct for typed errors of method get_browse_node_return_topics
GetBrowseNodeReturnTrendsError
struct for typed errors of method get_browse_node_return_trends
GetBrowseNodeReviewTopicsError
struct for typed errors of method get_browse_node_review_topics
GetBrowseNodeReviewTrendsError
struct for typed errors of method get_browse_node_review_trends
GetItemBrowseNodeError
struct for typed errors of method get_item_browse_node
GetItemReviewTopicsError
struct for typed errors of method get_item_review_topics
GetItemReviewTrendsError
struct for typed errors of method get_item_review_trends

Functions

get_browse_node_return_topics
Retrieve the topics that customers mention when they return items in a browse node.
get_browse_node_return_trends
Retrieve the trends of topics that customers mention when they return items in a browse node.
get_browse_node_review_topics
Retrieve a browse node’s ten most positive and ten most negative review topics.
get_browse_node_review_trends
Retrieve the positive and negative review trends of items in a browse node for the past six months.
get_item_browse_node
This API returns the associated browse node of the requested ASIN. A browse node is a location in a browse tree that is used for navigation, product classification, and website content on the Amazon retail website.
get_item_review_topics
Retrieve an item’s ten most positive and ten most negative review topics.
get_item_review_trends
Retrieve an item’s positive and negative review trends for the past six months.