Module definitions_api

Enums

GetDefinitionsProductTypeError
struct for typed errors of method get_definitions_product_type
SearchDefinitionsProductTypesError
struct for typed errors of method search_definitions_product_types

Functions

get_definitions_product_type
Retrieve an Amazon product type definition. Usage Plans: | Plan type | Rate (requests per second) | Burst | | –– | –– | –– | |Default| 5 | 10 | |Selling partner specific| Variable | Variable | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation. Rate limits for some selling partners will vary from the default rate and burst shown in the table above. For more information, see Usage Plans and Rate Limits in the Selling Partner API.
search_definitions_product_types
Search for and return a list of Amazon product types that have definitions available. Usage Plans: | Plan type | Rate (requests per second) | Burst | | –– | –– | –– | |Default| 5 | 10 | |Selling partner specific| Variable | Variable | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation. Rate limits for some selling partners will vary from the default rate and burst shown in the table above. For more information, see Usage Plans and Rate Limits in the Selling Partner API.