Function delete_inventory_item

pub async fn delete_inventory_item(
    configuration: &Configuration,
    seller_sku: &str,
    marketplace_id: &str,
) -> Result<DeleteInventoryItemResponse, Error<DeleteInventoryItemError>>
Requests that Amazon Deletes an item from the Sandbox Inventory in the sandbox environment. This is a sandbox-only operation and must be directed to a sandbox endpoint. Refer to Selling Partner API sandbox for more information.