Module fba_outbound_api

Module fba_outbound_api 

Enums

CancelFulfillmentOrderError
struct for typed errors of method cancel_fulfillment_order
CreateFulfillmentOrderError
struct for typed errors of method create_fulfillment_order
CreateFulfillmentReturnError
struct for typed errors of method create_fulfillment_return
DeliveryOffersError
struct for typed errors of method delivery_offers
GetFeatureInventoryError
struct for typed errors of method get_feature_inventory
GetFeatureSkuError
struct for typed errors of method get_feature_sku
GetFeaturesError
struct for typed errors of method get_features
GetFulfillmentOrderError
struct for typed errors of method get_fulfillment_order
GetFulfillmentPreviewError
struct for typed errors of method get_fulfillment_preview
GetPackageTrackingDetailsError
struct for typed errors of method get_package_tracking_details
ListAllFulfillmentOrdersError
struct for typed errors of method list_all_fulfillment_orders
ListReturnReasonCodesError
struct for typed errors of method list_return_reason_codes
SubmitFulfillmentOrderStatusUpdateError
struct for typed errors of method submit_fulfillment_order_status_update
UpdateFulfillmentOrderError
struct for typed errors of method update_fulfillment_order

Functions

cancel_fulfillment_order
Requests that Amazon stop attempting to fulfill the fulfillment order indicated by the specified order identifier. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
create_fulfillment_order
Requests that Amazon ship items from the seller’s inventory in Amazon’s fulfillment network to a destination address. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API
create_fulfillment_return
Creates a fulfillment return. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
delivery_offers
Returns delivery options that include an estimated delivery date and offer expiration, based on criteria that you specify. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 5 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
get_feature_inventory
Returns a list of inventory items that are eligible for the fulfillment feature you specify. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API..
get_feature_sku
Returns the number of items with the sellerSKU you specify that can have orders fulfilled using the specified feature. Note that if the sellerSKU isn’t eligible, the response will contain an empty skuInfo object. The parameters for this operation may contain special characters that require URL encoding. To avoid errors with SKUs when encoding URLs, refer to URL Encoding. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
get_features
Returns a list of features available for Multi-Channel Fulfillment orders in the marketplace you specify, and whether the seller for which you made the call is enrolled for each feature. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
get_fulfillment_order
Returns the fulfillment order indicated by the specified order identifier. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
get_fulfillment_preview
Returns a list of fulfillment order previews based on shipping criteria that you specify. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
get_package_tracking_details
Returns delivery tracking information for a package in an outbound shipment for a Multi-Channel Fulfillment order. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
list_all_fulfillment_orders
Returns a list of fulfillment orders fulfilled after (or at) a specified date-time, or indicated by the next token parameter. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API
list_return_reason_codes
Returns a list of return reason codes for a seller SKU in a given marketplace. The parameters for this operation may contain special characters that require URL encoding. To avoid errors with SKUs when encoding URLs, refer to URL Encoding. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
submit_fulfillment_order_status_update
Requests that Amazon update the status of an order in the sandbox testing environment. This is a sandbox-only operation and must be directed to a sandbox endpoint. Refer to Fulfillment Outbound Dynamic Sandbox Guide and Selling Partner API sandbox for more information.
update_fulfillment_order
Updates and/or requests shipment for a fulfillment order with an order hold on it. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 2 | 30 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.