Module sellers_api

Module sellers_api 

Enums

GetAccountError
struct for typed errors of method get_account
GetMarketplaceParticipationsError
struct for typed errors of method get_marketplace_participations

Functions

get_account
Returns information about a seller account and its marketplaces. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.016 | 15 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The preceding table indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.
get_marketplace_participations
Returns a list of marketplaces where the seller can list items and information about the seller’s participation in those marketplaces. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.016 | 15 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The preceding table indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits in the Selling Partner API.