create_claim

Function create_claim 

pub async fn create_claim(
    configuration: &Configuration,
    body: CreateClaimRequest,
    x_amzn_shipping_business_id: Option<&str>,
) -> Result<CreateClaimResponse, Error<CreateClaimError>>
This API will be used to create claim for single eligible shipment. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 80 | 100 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values then those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.