Module transactions_api

Enums

CreateTransactionError
struct for typed errors of method create_transaction
GetTransactionError
struct for typed errors of method get_transaction
ListAccountTransactionsError
struct for typed errors of method list_account_transactions

Functions

create_transaction
Create a transaction request from a Seller Wallet account to another customer-provided account.
get_transaction
Returns a transaction
list_account_transactions
Retrieve a list of transactions for a given Seller Wallet bank account.