Module transfer_preview_api

Enums

GetTransferPreviewError
struct for typed errors of method get_transfer_preview

Functions

get_transfer_preview
Returns list of potential fees on a transaction based on the source and destination country currency code