Function get_transfer_preview

pub async fn get_transfer_preview(
    configuration: &Configuration,
    source_country_code: &str,
    source_currency_code: &str,
    destination_country_code: &str,
    destination_currency_code: &str,
    base_amount: f64,
) -> Result<TransferRatePreview, Error<GetTransferPreviewError>>
Returns list of potential fees on a transaction based on the source and destination country currency code