Enums
- Create
Transfer Schedule Error - struct for typed errors of method
create_transfer_schedule - Delete
Schedule Transaction Error - struct for typed errors of method
delete_schedule_transaction - GetTransfer
Schedule Error - struct for typed errors of method
get_transfer_schedule - List
Transfer Schedules Error - struct for typed errors of method
list_transfer_schedules - Update
Transfer Schedule Error - struct for typed errors of method
update_transfer_schedule
Functions
- create_
transfer_ schedule - Create a transfer schedule request from a Seller Wallet account to another customer-provided account.
- delete_
schedule_ transaction - Delete a transaction request that is scheduled from a Seller Wallet account to another customer-provided account.
- get_
transfer_ schedule - Find a particular Seller Wallet account transfer schedule.
- list_
transfer_ schedules - Retrieve transfer schedules of a Seller Wallet bank account.
- update_
transfer_ schedule - Returns a transfer belonging to the updated scheduled transfer request