Module vendor_invoice_api

Enums

SubmitInvoiceError
struct for typed errors of method submit_invoice

Functions

submit_invoice
Submits one or more invoices for a vendor’s direct fulfillment orders. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.