Module vendor_shipping_api

Module vendor_shipping_api 

Enums

GetShipmentDetailsError
struct for typed errors of method get_shipment_details
GetShipmentLabelsError
struct for typed errors of method get_shipment_labels
SubmitShipmentConfirmationsError
struct for typed errors of method submit_shipment_confirmations
SubmitShipmentsError
struct for typed errors of method submit_shipments

Functions

get_shipment_details
Returns the Details about Shipment, Carrier Details, status of the shipment, container details and other details related to shipment based on the filter parameters value that you specify. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.
get_shipment_labels
Returns small parcel shipment labels based on the filters that you specify. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header contains the usage plan rate limits for the operation, when available. The preceding table contains the default rate and burst values for this operation. Selling partners whose business demands require higher throughput might have higher rate and burst values than those shown here. For more information, refer to Usage Plans and Rate Limits.
submit_shipment_confirmations
Submits one or more shipment confirmations for vendor orders. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.
submit_shipments
Submits one or more shipment request for vendor Orders. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 10 | 10 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.