Struct RateLimiter

pub struct RateLimiter { /* private fields */ }
In-memory rate limiter that manages token buckets for different endpoints Thread-safe but not cross-process

Implementations

Source

impl RateLimiter

pub fn new() -> Self

Examples found in repository?
examples/rate_limiter_test.rs (line 29)
26async fn main() -> Result<()> {
27    env_logger::init();
28
29    let rate_limiter = RateLimiter::new();
30
31    if let Err(e) = call_api_with_error(1, &rate_limiter, false).await {
32        println!("Call 1 failed: {}", e);
33    }
34
35    if let Err(e) = call_api_with_error(2, &rate_limiter, true).await {
36        println!("Call 2 failed: {}", e);
37    }
38
39    if let Err(e) = call_api_with_error(3, &rate_limiter, false).await {
40        println!("Call 3 failed: {}", e);
41    }
42
43    Ok(())
44}
pub async fn wait( &self, identifier: &str, rate: f64, burst: u32, ) -> Result<RateLimitGuard>

Wait for a token to become available for the given endpoint and return a guard When the guard is dropped, record_response will be called automatically

Examples found in repository?
examples/rate_limiter_test.rs (line 10)
5async fn call_api_with_error(
6    i: usize,
7    rate_limiter: &RateLimiter,
8    should_fail: bool,
9) -> Result<()> {
10    let guard = rate_limiter.wait("func1", 0.1, 1).await?;
11
12    println!("API call {} start at: {}", i, chrono::Local::now());
13
14    if should_fail {
15        return Err(anyhow::anyhow!("API call failed"));
16    }
17
18    tokio::time::sleep(Duration::from_secs(1)).await;
19    println!("API call {} end at  : {}", i, chrono::Local::now());
20
21    guard.mark_response().await;
22    Ok(())
23}
More examples
Hide additional examples
examples/sellers_v1_use_raw_api.rs (line 18)
6async fn main() -> Result<()> {
7    let spapi_config = SpapiConfig::from_env()?;
8    let spapi_client = SpapiClient::new(spapi_config.clone())?;
9    {
10        // Internally refresh the access token and create a configuration
11        // Configuration must be created for each API call
12        let configuration = spapi_client.create_configuration().await?;
13
14        // Wait for rate limit before making the API call
15        // When _guard is dropped, the rate limiter will mark the api call as having received a response
16        let _guard = spapi_client
17            .limiter()
18            .wait("get_marketplace_participations", 0.016, 15)
19            .await?;
20
21        // Call the API to get marketplace participations
22        let res = get_marketplace_participations(&configuration).await?;
23        
24        println!("Marketplace Participations: {:#?}", res);
25    }
26    Ok(())
27}
pub async fn check_token_availability(&self, identifier: &str) -> Result<bool>

Check if a token is available without consuming it

pub async fn get_token_status(&self) -> Result<HashMap<String, (f64, f64, u32)>>

Get current token status for all endpoints Returns (tokens, rate, burst) for each endpoint

pub async fn reset(&self)

Reset all rate limiting state (useful for testing)

pub async fn active_buckets_count(&self) -> usize

Get the number of active buckets