pub struct ContentDocument {
pub name: String,
pub content_type: ContentType,
pub content_sub_type: Option<String>,
pub locale: String,
pub content_module_list: Vec<ContentModule>,
}Expand description
ContentDocument : The A+ Content document. This is the enhanced content that is published to product detail pages.
Fields
name: StringThe A+ Content document name.
content_type: ContentTypecontent_sub_type: Option<String>The A+ Content document subtype. This represents a special-purpose type of an A+ Content document. Not every A+ Content document type has a subtype, and subtypes can change at any time.
locale: StringThe IETF language tag, which supports the primary language subtag and one secondary language subtag. The secondary language subtag is usually a regional designation. This doesn’t support subtags other than the primary and secondary subtags. Pattern: ^[a-z]{2,}-[A-Z0-9]{2,}$
content_module_list: Vec<ContentModule>A list of A+ Content modules.
Implementations
Sourceimpl ContentDocument
impl ContentDocument
Sourcepub fn new(
name: String,
content_type: ContentType,
locale: String,
content_module_list: Vec<ContentModule>,
) -> ContentDocument
pub fn new( name: String, content_type: ContentType, locale: String, content_module_list: Vec<ContentModule>, ) -> ContentDocument
The A+ Content document. This is the enhanced content that is published to product detail pages.