pub struct ContentModule {Show 16 fields
pub content_module_type: ContentModuleType,
pub standard_company_logo: Option<Box<StandardCompanyLogoModule>>,
pub standard_comparison_table: Option<Box<StandardComparisonTableModule>>,
pub standard_four_image_text: Option<Box<StandardFourImageTextModule>>,
pub standard_four_image_text_quadrant: Option<Box<StandardFourImageTextQuadrantModule>>,
pub standard_header_image_text: Option<Box<StandardHeaderImageTextModule>>,
pub standard_image_sidebar: Option<Box<StandardImageSidebarModule>>,
pub standard_image_text_overlay: Option<Box<StandardImageTextOverlayModule>>,
pub standard_multiple_image_text: Option<Box<StandardMultipleImageTextModule>>,
pub standard_product_description: Option<Box<StandardProductDescriptionModule>>,
pub standard_single_image_highlights: Option<Box<StandardSingleImageHighlightsModule>>,
pub standard_single_image_specs_detail: Option<Box<StandardSingleImageSpecsDetailModule>>,
pub standard_single_side_image: Option<Box<StandardSingleSideImageModule>>,
pub standard_tech_specs: Option<Box<StandardTechSpecsModule>>,
pub standard_text: Option<Box<StandardTextModule>>,
pub standard_three_image_text: Option<Box<StandardThreeImageTextModule>>,
}Expand description
ContentModule : An A+ Content module. An A+ Content document is composed of content modules. The contentModuleType property selects which content module types to use.
Fields
content_module_type: ContentModuleTypestandard_company_logo: Option<Box<StandardCompanyLogoModule>>standard_comparison_table: Option<Box<StandardComparisonTableModule>>standard_four_image_text: Option<Box<StandardFourImageTextModule>>standard_four_image_text_quadrant: Option<Box<StandardFourImageTextQuadrantModule>>standard_header_image_text: Option<Box<StandardHeaderImageTextModule>>standard_image_text_overlay: Option<Box<StandardImageTextOverlayModule>>standard_multiple_image_text: Option<Box<StandardMultipleImageTextModule>>standard_product_description: Option<Box<StandardProductDescriptionModule>>standard_single_image_highlights: Option<Box<StandardSingleImageHighlightsModule>>standard_single_image_specs_detail: Option<Box<StandardSingleImageSpecsDetailModule>>standard_single_side_image: Option<Box<StandardSingleSideImageModule>>standard_tech_specs: Option<Box<StandardTechSpecsModule>>standard_text: Option<Box<StandardTextModule>>standard_three_image_text: Option<Box<StandardThreeImageTextModule>>Implementations
Sourceimpl ContentModule
impl ContentModule
Sourcepub fn new(content_module_type: ContentModuleType) -> ContentModule
pub fn new(content_module_type: ContentModuleType) -> ContentModule
An A+ Content module. An A+ Content document is composed of content modules. The contentModuleType property selects which content module types to use.