pub struct ImageCropSpecification {
pub size: Box<ImageDimensions>,
pub offset: Option<Box<ImageOffsets>>,
}Expand description
ImageCropSpecification : The instructions for optionally cropping an image. If you don’t want to crop the image, set the dimensions to the original image size. If the image is cropped and you don’t include offset values, the coordinates of the top left corner of the cropped image are set to (0,0) by default.
Fields
size: Box<ImageDimensions>offset: Option<Box<ImageOffsets>>Implementations
Sourceimpl ImageCropSpecification
impl ImageCropSpecification
Sourcepub fn new(size: ImageDimensions) -> ImageCropSpecification
pub fn new(size: ImageDimensions) -> ImageCropSpecification
The instructions for optionally cropping an image. If you don’t want to crop the image, set the dimensions to the original image size. If the image is cropped and you don’t include offset values, the coordinates of the top left corner of the cropped image are set to (0,0) by default.