pub struct ImageDimensions {
pub width: Box<IntegerWithUnits>,
pub height: Box<IntegerWithUnits>,
}Expand description
ImageDimensions : The dimensions that extend from the top left corner of the image (this applies to cropped and uncropped images). ImageDimensions units must be in pixels.
Fields
width: Box<IntegerWithUnits>height: Box<IntegerWithUnits>Implementations
Sourceimpl ImageDimensions
impl ImageDimensions
Sourcepub fn new(width: IntegerWithUnits, height: IntegerWithUnits) -> ImageDimensions
pub fn new(width: IntegerWithUnits, height: IntegerWithUnits) -> ImageDimensions
The dimensions that extend from the top left corner of the image (this applies to cropped and uncropped images). ImageDimensions units must be in pixels.