pub struct ImageOffsets {
pub x: Box<IntegerWithUnits>,
pub y: Box<IntegerWithUnits>,
}Expand description
ImageOffsets : The top left corner of the cropped image, specified in the original image’s coordinate space.
Fields
x: Box<IntegerWithUnits>y: Box<IntegerWithUnits>Implementations
Sourceimpl ImageOffsets
impl ImageOffsets
Sourcepub fn new(x: IntegerWithUnits, y: IntegerWithUnits) -> ImageOffsets
pub fn new(x: IntegerWithUnits, y: IntegerWithUnits) -> ImageOffsets
The top left corner of the cropped image, specified in the original image’s coordinate space.