pub struct ParagraphComponent {
pub text_list: Vec<TextComponent>,
}Expand description
ParagraphComponent : A list of rich text content that is typically presented in a text box.
Fields
text_list: Vec<TextComponent>Implementations
Sourceimpl ParagraphComponent
impl ParagraphComponent
Sourcepub fn new(text_list: Vec<TextComponent>) -> ParagraphComponent
pub fn new(text_list: Vec<TextComponent>) -> ParagraphComponent
A list of rich text content that is typically presented in a text box.