pub struct StandardTextBlock {
pub headline: Option<Box<TextComponent>>,
pub body: Option<Box<ParagraphComponent>>,
}Expand description
StandardTextBlock : The A+ Content standard text box block, which contains a paragraph and a headline.
Fields
headline: Option<Box<TextComponent>>body: Option<Box<ParagraphComponent>>Implementations
Sourceimpl StandardTextBlock
impl StandardTextBlock
Sourcepub fn new() -> StandardTextBlock
pub fn new() -> StandardTextBlock
The A+ Content standard text box block, which contains a paragraph and a headline.