pub struct CreateNotificationRequest {
pub template_id: String,
pub notification_parameters: HashMap<String, Value>,
pub marketplace_id: Option<String>,
}Expand description
CreateNotificationRequest : The request for the createNotification operation.
Fields
template_id: StringThe unique identifier of the notification template you used to onboard your application.
notification_parameters: HashMap<String, Value>The dynamic parameters required by the notification templated specified by templateId.
marketplace_id: Option<String>An encrypted marketplace identifier for the posted notification.
Implementations