pub struct DeleteNotificationsRequest {
pub template_id: String,
pub deletion_reason: DeletionReason,
}Expand description
DeleteNotificationsRequest : The request for the deleteNotifications operation.
Fields
template_id: StringThe unique identifier of the notification template you used to onboard your application.
deletion_reason: DeletionReasonThe unique identifier that maps each notification status to a reason code.
Implementations
Sourceimpl DeleteNotificationsRequest
impl DeleteNotificationsRequest
Sourcepub fn new(
template_id: String,
deletion_reason: DeletionReason,
) -> DeleteNotificationsRequest
pub fn new( template_id: String, deletion_reason: DeletionReason, ) -> DeleteNotificationsRequest
The request for the deleteNotifications operation.