pub struct Address {
pub address_line1: String,
pub address_line2: Option<String>,
pub address_line3: Option<String>,
pub city: Option<String>,
pub country_code: String,
pub county: Option<String>,
pub district: Option<String>,
pub name: String,
pub phone_number: Option<String>,
pub postal_code: Option<String>,
pub state_or_region: String,
}Expand description
Address : Shipping address that represents the origin or destination location.
Fields
address_line1: StringFirst line of the address text.
address_line2: Option<String>Optional second line of the address text.
address_line3: Option<String>Optional third line of the address text.
city: Option<String>Optional city where this address is located.
country_code: StringTwo-digit, ISO 3166-1 alpha-2 formatted country code where this address is located.
county: Option<String>Optional county where this address is located.
district: Option<String>Optional district where this address is located.
name: StringName of the person, business, or institution at this address.
phone_number: Option<String>Optional E.164-formatted phone number for an available contact at this address.
postal_code: Option<String>Optional postal code where this address is located.
state_or_region: StringState or region where this address is located. Note that this is contextual to the specified country code.
Implementations