pub struct InventoryQuantity {
pub quantity: f64,
pub unit_of_measurement: InventoryUnitOfMeasurement,
}Expand description
InventoryQuantity : Quantity of inventory with an associated measurement unit context.
Fields
quantity: f64Quantity of the respective inventory.
unit_of_measurement: InventoryUnitOfMeasurementImplementations
Sourceimpl InventoryQuantity
impl InventoryQuantity
Sourcepub fn new(
quantity: f64,
unit_of_measurement: InventoryUnitOfMeasurement,
) -> InventoryQuantity
pub fn new( quantity: f64, unit_of_measurement: InventoryUnitOfMeasurement, ) -> InventoryQuantity
Quantity of inventory with an associated measurement unit context.