Item

pub struct Item {
    pub asin: String,
    pub attributes: Option<HashMap<String, Value>>,
    pub identifiers: Option<Vec<ItemIdentifiersByMarketplace>>,
    pub images: Option<Vec<ItemImagesByMarketplace>>,
    pub product_types: Option<Vec<ItemProductTypeByMarketplace>>,
    pub sales_ranks: Option<Vec<ItemSalesRanksByMarketplace>>,
    pub summaries: Option<Vec<ItemSummaryByMarketplace>>,
    pub variations: Option<Vec<ItemVariationsByMarketplace>>,
    pub vendor_details: Option<Vec<ItemVendorDetailsByMarketplace>>,
}
Item : An item in the Amazon catalog.

Fields

asin: String

Amazon Standard Identification Number (ASIN) is the unique identifier for an item in the Amazon catalog.

attributes: Option<HashMap<String, Value>>

A JSON object that contains structured item attribute data keyed by attribute name. Catalog item attributes are available only to brand owners and conform to the related product type definitions available in the Selling Partner API for Product Type Definitions.

identifiers: Option<Vec<ItemIdentifiersByMarketplace>>

Identifiers associated with the item in the Amazon catalog, such as UPC and EAN identifiers.

images: Option<Vec<ItemImagesByMarketplace>>

Images for an item in the Amazon catalog. All image variants are provided to brand owners. Otherwise, a thumbnail of the "MAIN" image variant is provided.

product_types: Option<Vec<ItemProductTypeByMarketplace>>

Product types associated with the Amazon catalog item.

sales_ranks: Option<Vec<ItemSalesRanksByMarketplace>>

Sales ranks of an Amazon catalog item.

summaries: Option<Vec<ItemSummaryByMarketplace>>

Summary details of an Amazon catalog item.

variations: Option<Vec<ItemVariationsByMarketplace>>

Variation details by marketplace for an Amazon catalog item (variation relationships).

vendor_details: Option<Vec<ItemVendorDetailsByMarketplace>>

Vendor details associated with an Amazon catalog item. Vendor details are available to vendors only.

Implementations

Source

impl Item

pub fn new(asin: String) -> Item

An item in the Amazon catalog.