Item

pub struct Item {
    pub asin: String,
    pub attributes: Option<HashMap<String, Value>>,
    pub classifications: Option<Vec<ItemBrowseClassificationsByMarketplace>>,
    pub dimensions: Option<Vec<ItemDimensionsByMarketplace>>,
    pub identifiers: Option<Vec<ItemIdentifiersByMarketplace>>,
    pub images: Option<Vec<ItemImagesByMarketplace>>,
    pub product_types: Option<Vec<ItemProductTypeByMarketplace>>,
    pub relationships: Option<Vec<ItemRelationshipsByMarketplace>>,
    pub sales_ranks: Option<Vec<ItemSalesRanksByMarketplace>>,
    pub summaries: Option<Vec<ItemSummaryByMarketplace>>,
    pub vendor_details: Option<Vec<ItemVendorDetailsByMarketplace>>,
}
Item : An item in the Amazon catalog.

Fields

asin: String

The unique identifier of an item in the Amazon catalog.

attributes: Option<HashMap<String, Value>>

A JSON object containing structured item attribute data that is keyed by attribute name. Catalog item attributes conform to the related Amazon product type definitions that you can get from the Product Type Definitions API.

classifications: Option<Vec<ItemBrowseClassificationsByMarketplace>>

An array of classifications (browse nodes) that is associated with the item in the Amazon catalog, grouped by marketplaceId.

dimensions: Option<Vec<ItemDimensionsByMarketplace>>

An array of dimensions that are associated with the item in the Amazon catalog, grouped by marketplaceId.

identifiers: Option<Vec<ItemIdentifiersByMarketplace>>

Identifiers associated with the item in the Amazon catalog, such as UPC and EAN identifiers.

images: Option<Vec<ItemImagesByMarketplace>>

The images for an item in the Amazon catalog.

product_types: Option<Vec<ItemProductTypeByMarketplace>>

Product types that are associated with the Amazon catalog item.

relationships: Option<Vec<ItemRelationshipsByMarketplace>>

Relationships grouped by marketplaceId for an Amazon catalog item (for example, variations).

sales_ranks: Option<Vec<ItemSalesRanksByMarketplace>>

Sales ranks of an Amazon catalog item.

summaries: Option<Vec<ItemSummaryByMarketplace>>

Summaries of Amazon catalog items.

vendor_details: Option<Vec<ItemVendorDetailsByMarketplace>>

The vendor details that are associated with an Amazon catalog item. Vendor details are only available to vendors.

Implementations

Source

impl Item

pub fn new(asin: String) -> Item

An item in the Amazon catalog.