pub struct BrowseNodeResponse {
pub browse_node_id: String,
pub display_name: String,
}Expand description
BrowseNodeResponse : The response for the getItemBrowseNode operation.
Fields
browse_node_id: StringA browse node id is the unique identifier of a given browse node. A browse node is a location in a browse tree that is used for navigation, product classification, and website content.
display_name: StringThe display name of the browse node as visible on the Amazon retail website.
Implementations
Sourceimpl BrowseNodeResponse
impl BrowseNodeResponse
Sourcepub fn new(browse_node_id: String, display_name: String) -> BrowseNodeResponse
pub fn new(browse_node_id: String, display_name: String) -> BrowseNodeResponse
The response for the getItemBrowseNode operation.