pub struct GetDocumentResponse {
pub document_id: String,
pub document_url: String,
}Expand description
GetDocumentResponse : The response for the getDocument operation.
Fields
document_id: StringThe identifier for the Data Kiosk document. This identifier is unique only in combination with a selling partner account ID.
document_url: StringA presigned URL that can be used to retrieve the Data Kiosk document. This URL expires after 5 minutes. If the Data Kiosk document is compressed, the Content-Encoding header will indicate the compression algorithm. Note: Most HTTP clients are capable of automatically decompressing downloaded files based on the Content-Encoding header.
Implementations
Sourceimpl GetDocumentResponse
impl GetDocumentResponse
Sourcepub fn new(document_id: String, document_url: String) -> GetDocumentResponse
pub fn new(document_id: String, document_url: String) -> GetDocumentResponse
The response for the getDocument operation.