pub struct AddInventoryRequest {
pub inventory_items: Option<Vec<InventoryItem>>,
}Expand description
AddInventoryRequest : The object with the list of Inventory to be added
Fields
inventory_items: Option<Vec<InventoryItem>>List of Inventory to be added
Implementations
Sourceimpl AddInventoryRequest
impl AddInventoryRequest
Sourcepub fn new() -> AddInventoryRequest
pub fn new() -> AddInventoryRequest
The object with the list of Inventory to be added