pub struct Feed {
pub feed_id: String,
pub feed_type: String,
pub marketplace_ids: Option<Vec<String>>,
pub created_time: String,
pub processing_status: ProcessingStatus,
pub processing_start_time: Option<String>,
pub processing_end_time: Option<String>,
pub result_feed_document_id: Option<String>,
}Expand description
Feed : Detailed information about the feed.
Fields
feed_id: StringThe identifier for the feed. This identifier is unique only in combination with a seller ID.
feed_type: StringThe feed type.
marketplace_ids: Option<Vec<String>>A list of identifiers for the marketplaces that the feed is applied to.
created_time: StringThe date and time when the feed was created, in ISO 8601 date time format.
processing_status: ProcessingStatusThe processing status of the feed.
processing_start_time: Option<String>The date and time when feed processing started, in ISO 8601 date time format.
processing_end_time: Option<String>The date and time when feed processing completed, in ISO 8601 date time format.
result_feed_document_id: Option<String>The identifier for the feed document. This identifier is unique only in combination with a seller ID.
Implementations