pub struct Breakdown {
pub breakdown_type: Option<String>,
pub breakdown_amount: Option<Box<Currency>>,
pub breakdowns: Option<Vec<Breakdown>>,
}Expand description
Breakdown : Breakdown provides details regarding the money movement under the financial transaction. Breakdowns get categorized further into breakdown types, breakdown amounts, and further breakdowns into a hierarchical structure.
Fields
breakdown_type: Option<String>The type of charge.
breakdown_amount: Option<Box<Currency>>breakdowns: Option<Vec<Breakdown>>A list of breakdowns that detail how the total amount is calculated for the transaction.
Implementations