pub struct Transaction {
pub selling_partner_metadata: Option<Box<SellingPartnerMetadata>>,
pub related_identifiers: Option<Vec<RelatedIdentifier>>,
pub transaction_type: Option<String>,
pub transaction_id: Option<String>,
pub transaction_status: Option<String>,
pub description: Option<String>,
pub posted_date: Option<String>,
pub total_amount: Option<Box<Currency>>,
pub marketplace_details: Option<Box<MarketplaceDetails>>,
pub items: Option<Vec<Item>>,
pub contexts: Option<Vec<Context>>,
pub breakdowns: Option<Vec<Breakdown>>,
}Expand description
Transaction : Contains all information related to the transaction.
Fields
selling_partner_metadata: Option<Box<SellingPartnerMetadata>>Related business identifiers of the transaction.
transaction_type: Option<String>The type of transaction. Possible values: * Shipment
transaction_id: Option<String>The unique identifier for the transaction.
transaction_status: Option<String>The status of the transaction. Possible values: * DEFERRED: the transaction is currently deferred. * RELEASED: the transaction is currently released. * DEFERRED_RELEASED: the transaction was deferred in the past, but is now released. The status of a deferred transaction is updated to DEFERRED_RELEASED when the transaction is released.
description: Option<String>Describes the reasons for the transaction. Example: ‘Order Payment’,‘Refund Order’
posted_date: Option<String>Fields with a schema type of date are in ISO 8601 date time format (for example GroupBeginDate).
total_amount: Option<Box<Currency>>marketplace_details: Option<Box<MarketplaceDetails>>items: Option<Vec<Item>>List of items in the transaction
contexts: Option<Vec<Context>>List of additional Information about the item.
breakdowns: Option<Vec<Breakdown>>A list of breakdowns that detail how the total amount is calculated for the transaction.
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub fn new() -> Transaction
pub fn new() -> Transaction
Contains all information related to the transaction.