pub struct FinancialEventGroup {
pub financial_event_group_id: Option<String>,
pub processing_status: Option<String>,
pub fund_transfer_status: Option<String>,
pub original_total: Option<Box<Currency>>,
pub converted_total: Option<Box<Currency>>,
pub fund_transfer_date: Option<String>,
pub trace_id: Option<String>,
pub account_tail: Option<String>,
pub beginning_balance: Option<Box<Currency>>,
pub financial_event_group_start: Option<String>,
pub financial_event_group_end: Option<String>,
}Expand description
FinancialEventGroup : Information related to a financial event group.
Fields
financial_event_group_id: Option<String>A unique identifier for the financial event group.
processing_status: Option<String>The processing status of the financial event group indicates whether the balance of the financial event group is settled. Possible values: * Open * Closed
fund_transfer_status: Option<String>The status of the fund transfer.
original_total: Option<Box<Currency>>converted_total: Option<Box<Currency>>fund_transfer_date: Option<String>Fields with a schema type of date are in ISO 8601 date time format (for example GroupBeginDate).
trace_id: Option<String>The trace identifier used by sellers to look up transactions externally.
account_tail: Option<String>The account tail of the payment instrument.
beginning_balance: Option<Box<Currency>>financial_event_group_start: Option<String>Fields with a schema type of date are in ISO 8601 date time format (for example GroupBeginDate).
financial_event_group_end: Option<String>Fields with a schema type of date are in ISO 8601 date time format (for example GroupBeginDate).
Implementations
Sourceimpl FinancialEventGroup
impl FinancialEventGroup
Sourcepub fn new() -> FinancialEventGroup
pub fn new() -> FinancialEventGroup
Information related to a financial event group.