pub struct SolutionProviderCreditEvent {
pub provider_transaction_type: Option<String>,
pub seller_order_id: Option<String>,
pub marketplace_id: Option<String>,
pub marketplace_country_code: Option<String>,
pub seller_id: Option<String>,
pub seller_store_name: Option<String>,
pub provider_id: Option<String>,
pub provider_store_name: Option<String>,
pub transaction_amount: Option<Box<Currency>>,
pub transaction_creation_date: Option<String>,
}Expand description
SolutionProviderCreditEvent : A credit given to a solution provider.
Fields
provider_transaction_type: Option<String>The transaction type.
seller_order_id: Option<String>A seller-defined identifier for an order.
marketplace_id: Option<String>The identifier of the marketplace where the order was placed.
marketplace_country_code: Option<String>The two-letter country code of the country associated with the marketplace where the order was placed.
seller_id: Option<String>The Amazon-defined identifier of the seller.
seller_store_name: Option<String>The store name where the payment event occurred.
provider_id: Option<String>The Amazon-defined identifier of the solution provider.
provider_store_name: Option<String>The store name where the payment event occurred.
transaction_amount: Option<Box<Currency>>transaction_creation_date: Option<String>Fields with a schema type of date are in ISO 8601 date time format (for example GroupBeginDate).
Implementations
Sourceimpl SolutionProviderCreditEvent
impl SolutionProviderCreditEvent
Sourcepub fn new() -> SolutionProviderCreditEvent
pub fn new() -> SolutionProviderCreditEvent
A credit given to a solution provider.