pub struct BoxUpdateInput {
pub content_information_source: BoxContentInformationSource,
pub dimensions: Box<Dimensions>,
pub items: Option<Vec<ItemInput>>,
pub package_id: Option<String>,
pub quantity: i32,
pub weight: Box<Weight>,
}Expand description
BoxUpdateInput : Input information for updating a box
Fields
content_information_source: BoxContentInformationSourcedimensions: Box<Dimensions>items: Option<Vec<ItemInput>>The items and their quantity in the box. This must be empty if the box contentInformationSource is BARCODE_2D or MANUAL_PROCESS.
package_id: Option<String>Primary key to uniquely identify a Box Package. PackageId must be provided if the intent is to update an existing box. Adding a new box will not require providing this value. Any existing PackageIds not provided will be treated as to-be-removed
quantity: i32The number of containers where all other properties like weight or dimensions are identical.
weight: Box<Weight>Implementations
Sourceimpl BoxUpdateInput
impl BoxUpdateInput
Sourcepub fn new(
content_information_source: BoxContentInformationSource,
dimensions: Dimensions,
quantity: i32,
weight: Weight,
) -> BoxUpdateInput
pub fn new( content_information_source: BoxContentInformationSource, dimensions: Dimensions, quantity: i32, weight: Weight, ) -> BoxUpdateInput
Input information for updating a box