pub struct Address {
pub name: String,
pub address_line1: String,
pub address_line2: Option<String>,
pub address_line3: Option<String>,
pub city: Option<String>,
pub district_or_county: Option<String>,
pub state_or_region: String,
pub postal_code: String,
pub country_code: String,
pub phone: Option<String>,
}Expand description
Address : A physical address.
Fields
name: StringThe name of the person, business or institution at the address.
address_line1: StringThe first line of the address.
address_line2: Option<String>Additional address information, if required.
address_line3: Option<String>Additional address information, if required.
city: Option<String>The city where the person, business, or institution is located. This property is required in all countries except Japan. It should not be used in Japan.
district_or_county: Option<String>The district or county where the person, business, or institution is located.
state_or_region: StringThe state or region where the person, business or institution is located.
postal_code: StringThe postal code of the address.
country_code: StringThe two digit country code. In ISO 3166-1 alpha-2 format.
phone: Option<String>The phone number of the person, business, or institution located at the address.
Implementations