pub struct VariablePrecisionAddress {
pub address_line1: Option<String>,
pub address_line2: Option<String>,
pub address_line3: Option<String>,
pub city: Option<String>,
pub district_or_county: Option<String>,
pub state_or_region: Option<String>,
pub postal_code: String,
pub country_code: String,
}Expand description
VariablePrecisionAddress : A physical address with varying degrees of precision. A more precise address can provide more accurate results than country code and postal code alone.
Fields
address_line1: Option<String>The first line of the address.
address_line2: Option<String>Additional address information, if required.
address_line3: Option<String>Additional address information, if required.
city: Option<String>The city where the person, business, or institution is located. This property should not be used in Japan.
district_or_county: Option<String>The district or county where the person, business, or institution is located.
state_or_region: Option<String>The state or region where the person, business or institution is located.
postal_code: StringThe postal code of the address.
country_code: StringThe two digit country code. In ISO 3166-1 alpha-2 format.
Implementations
Sourceimpl VariablePrecisionAddress
impl VariablePrecisionAddress
Sourcepub fn new(
postal_code: String,
country_code: String,
) -> VariablePrecisionAddress
pub fn new( postal_code: String, country_code: String, ) -> VariablePrecisionAddress
A physical address with varying degrees of precision. A more precise address can provide more accurate results than country code and postal code alone.