pub struct Issue {
pub code: String,
pub message: String,
pub severity: Severity,
pub attribute_names: Option<Vec<String>>,
pub categories: Vec<String>,
pub enforcements: Option<Box<IssueEnforcements>>,
}Expand description
Issue : An issue with a listings item.
Fields
code: StringAn issue code that identifies the type of issue.
message: StringA message that describes the issue.
severity: SeverityThe severity of the issue.
attribute_names: Option<Vec<String>>The names of the attributes associated with the issue, if applicable.
categories: Vec<String>List of issue categories. Possible values: * ‘INVALID_ATTRIBUTE’ - Indicating an invalid attribute in the listing. * ‘MISSING_ATTRIBUTE’ - Highlighting a missing attribute in the listing. * ‘INVALID_IMAGE’ - Signifying an invalid image in the listing. * ‘MISSING_IMAGE’ - Noting the absence of an image in the listing. * ‘INVALID_PRICE’ - Pertaining to issues with the listing’s price-related attributes. * ‘MISSING_PRICE’ - Pointing out the absence of a price attribute in the listing. * ‘DUPLICATE’ - Identifying listings with potential duplicate problems, such as this ASIN potentially being a duplicate of another ASIN. * ‘QUALIFICATION_REQUIRED’ - Indicating that the listing requires qualification-related approval.
enforcements: Option<Box<IssueEnforcements>>