pub struct ProcessingDirective {
pub event_filter: Option<Box<EventFilter>>,
}Expand description
ProcessingDirective : Additional information passed to the subscription to control the processing of notifications. For example, you can use an eventFilter to customize your subscription to send notifications for only the specified marketplaceIds, or select the aggregation time period at which to send notifications (for example: limit to one notification every five minutes for high frequency notifications). The specific features available vary depending on the notificationType. This feature is currently only supported by the ANY_OFFER_CHANGED and ORDER_CHANGE notificationTypes.
Fields
event_filter: Option<Box<EventFilter>>Implementations
Sourceimpl ProcessingDirective
impl ProcessingDirective
Sourcepub fn new() -> ProcessingDirective
pub fn new() -> ProcessingDirective
Additional information passed to the subscription to control the processing of notifications. For example, you can use an eventFilter to customize your subscription to send notifications for only the specified marketplaceIds, or select the aggregation time period at which to send notifications (for example: limit to one notification every five minutes for high frequency notifications). The specific features available vary depending on the notificationType. This feature is currently only supported by the ANY_OFFER_CHANGED and ORDER_CHANGE notificationTypes.