pub enum OptionalFulfillmentProgram {
FbaCore,
FbaSnl,
FbaEfn,
}Expand description
OptionalFulfillmentProgram : An optional enrollment program to return the estimated fees when the offer is fulfilled by Amazon (IsAmazonFulfilled is set to true). An optional enrollment program to return the estimated fees when the offer is fulfilled by Amazon (IsAmazonFulfilled is set to true).
Variants