Points

pub struct Points {
    pub points_number: Option<i32>,
    pub points_monetary_value: Option<Box<MoneyType>>,
}
Points : The number of Amazon Points that are offered with the purchase of an item and the monetary value of these points.

Fields

points_number: Option<i32>

The number of Amazon Points.

points_monetary_value: Option<Box<MoneyType>>

Implementations

Source

impl Points

pub fn new() -> Points

The number of Amazon Points that are offered with the purchase of an item and the monetary value of these points.