Module http_method

Module http_method 

Enums

HttpMethod
HttpMethod : The HTTP method associated with the individual APIs being called as part of the batch request. The HTTP method associated with the individual APIs being called as part of the batch request.