pub enum ItemCondition {
New,
Used,
Collectible,
Refurbished,
Club,
}Expand description
ItemCondition : Filters the offer listings to be considered based on item condition. Possible values: New, Used, Collectible, Refurbished, Club. Filters the offer listings to be considered based on item condition. Possible values: New, Used, Collectible, Refurbished, Club.
Variants