pub struct OfferProgramConfigurationPromotions {
pub selling_partner_funded_base_discount: Option<Box<OfferProgramConfigurationPromotionsDiscountFunding>>,
pub selling_partner_funded_tiered_discount: Option<Box<OfferProgramConfigurationPromotionsDiscountFunding>>,
pub amazon_funded_base_discount: Option<Box<OfferProgramConfigurationPromotionsDiscountFunding>>,
pub amazon_funded_tiered_discount: Option<Box<OfferProgramConfigurationPromotionsDiscountFunding>>,
}Expand description
OfferProgramConfigurationPromotions : An object which represents all promotions applied to an offer.
Fields
selling_partner_funded_base_discount: Option<Box<OfferProgramConfigurationPromotionsDiscountFunding>>selling_partner_funded_tiered_discount: Option<Box<OfferProgramConfigurationPromotionsDiscountFunding>>amazon_funded_base_discount: Option<Box<OfferProgramConfigurationPromotionsDiscountFunding>>amazon_funded_tiered_discount: Option<Box<OfferProgramConfigurationPromotionsDiscountFunding>>Implementations
Sourceimpl OfferProgramConfigurationPromotions
impl OfferProgramConfigurationPromotions
Sourcepub fn new() -> OfferProgramConfigurationPromotions
pub fn new() -> OfferProgramConfigurationPromotions
An object which represents all promotions applied to an offer.