Report

Struct Report 

pub struct Report {
    pub marketplace_ids: Option<Vec<String>>,
    pub report_id: String,
    pub report_type: String,
    pub data_start_time: Option<String>,
    pub data_end_time: Option<String>,
    pub report_schedule_id: Option<String>,
    pub created_time: String,
    pub processing_status: ProcessingStatus,
    pub processing_start_time: Option<String>,
    pub processing_end_time: Option<String>,
    pub report_document_id: Option<String>,
}
Report : Detailed information about the report.

Fields

marketplace_ids: Option<Vec<String>>

A list of marketplace identifiers for the report.

report_id: String

The identifier for the report. This identifier is unique only in combination with a seller ID.

report_type: String

The report type. Refer to Report Type Values for more information.

data_start_time: Option<String>

The start of a date and time range used for selecting the data to report.

data_end_time: Option<String>

The end of a date and time range used for selecting the data to report.

report_schedule_id: Option<String>

The identifier of the report schedule that created this report (if any). This identifier is unique only in combination with a seller ID.

created_time: String

The date and time when the report was created.

processing_status: ProcessingStatus

The processing status of the report.

processing_start_time: Option<String>

The date and time when the report processing started, in ISO 8601 date time format.

processing_end_time: Option<String>

The date and time when the report processing completed, in ISO 8601 date time format.

report_document_id: Option<String>

The identifier for the report document. Pass this into the getReportDocument operation to get the information you will need to retrieve the report document’s contents.

Implementations

Source

impl Report

pub fn new( report_id: String, report_type: String, created_time: String, processing_status: ProcessingStatus, ) -> Report

Detailed information about the report.