pub struct Participation {
pub is_participating: bool,
pub has_suspended_listings: bool,
}Expand description
Participation : Information that is specific to a seller in a marketplace.
Fields
is_participating: boolIf true, the seller participates in the marketplace. Otherwise false.
has_suspended_listings: boolSpecifies if the seller has suspended listings. true if the seller Listing Status is set to Inactive, otherwise false.
Implementations
Sourceimpl Participation
impl Participation
Sourcepub fn new(
is_participating: bool,
has_suspended_listings: bool,
) -> Participation
pub fn new( is_participating: bool, has_suspended_listings: bool, ) -> Participation
Information that is specific to a seller in a marketplace.