Module fixed_slot_capacity_query

Module fixed_slot_capacity_query 

Structs

FixedSlotCapacityQuery
FixedSlotCapacityQuery : Request schema for the getFixedSlotCapacity operation. This schema is used to define the time range, capacity types and slot duration which are being queried.