pub struct GetAppointmentSlotsResponse {
pub payload: Option<Box<AppointmentSlotReport>>,
pub errors: Option<Vec<Error>>,
}Expand description
GetAppointmentSlotsResponse : The response of fetching appointment slots based on service context.
Fields
payload: Option<Box<AppointmentSlotReport>>errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
Sourceimpl GetAppointmentSlotsResponse
impl GetAppointmentSlotsResponse
Sourcepub fn new() -> GetAppointmentSlotsResponse
pub fn new() -> GetAppointmentSlotsResponse
The response of fetching appointment slots based on service context.