pub struct JobListing {
pub total_result_size: Option<i32>,
pub next_page_token: Option<String>,
pub previous_page_token: Option<String>,
pub jobs: Option<Vec<ServiceJob>>,
}Expand description
JobListing : The payload for the getServiceJobs operation.
Fields
total_result_size: Option<i32>Total result size of the query result.
next_page_token: Option<String>A generated string used to pass information to your next request. If nextPageToken is returned, pass the value of nextPageToken to the pageToken to get next results.
previous_page_token: Option<String>A generated string used to pass information to your next request. If previousPageToken is returned, pass the value of previousPageToken to the pageToken to get previous page results.
jobs: Option<Vec<ServiceJob>>List of job details for the given input.
Implementations
Sourceimpl JobListing
impl JobListing
Sourcepub fn new() -> JobListing
pub fn new() -> JobListing
The payload for the getServiceJobs operation.