Structs
- Range
Slot Capacity Query - RangeSlotCapacityQuery : Request schema for the
getRangeSlotCapacityoperation. This schema is used to define the time range and capacity types that are being queried.
getRangeSlotCapacity operation. This schema is used to define the time range and capacity types that are being queried.