Structs
- Update
Reservation Record - UpdateReservationRecord :
UpdateReservationRecordentity contains theReservationif there is an error/warning while performing the requested operation on it, otherwise it will contain the newreservationId.
UpdateReservationRecord entity contains the Reservation if there is an error/warning while performing the requested operation on it, otherwise it will contain the new reservationId.