pub struct Address {
pub name: String,
pub address_line1: String,
pub address_line2: Option<String>,
pub address_line3: Option<String>,
pub company_name: Option<String>,
pub state_or_region: String,
pub city: String,
pub country_code: String,
pub postal_code: String,
pub email: Option<String>,
pub phone_number: Option<String>,
pub geocode: Option<Box<Geocode>>,
}Expand description
Address : The address.
Fields
name: StringThe name of the person, business or institution at the address.
address_line1: StringThe first line of the address.
address_line2: Option<String>Additional address information, if required.
address_line3: Option<String>Additional address information, if required.
company_name: Option<String>The name of the business or institution associated with the address.
state_or_region: StringThe state, county or region where the person, business or institution is located.
city: StringThe city or town where the person, business or institution is located.
country_code: StringThe two digit country code. Follows ISO 3166-1 alpha-2 format.
postal_code: StringThe postal code of that address. It contains a series of letters or digits or both, sometimes including spaces or punctuation.
email: Option<String>The email address of the contact associated with the address.
phone_number: Option<String>The phone number of the person, business or institution located at that address, including the country calling code.
geocode: Option<Box<Geocode>>