pub struct AvailableValueAddedServiceGroup {
pub group_id: String,
pub group_description: String,
pub is_required: bool,
pub value_added_services: Option<Vec<ValueAddedService>>,
}Expand description
AvailableValueAddedServiceGroup : The value-added services available for purchase with a shipping service offering.
Fields
group_id: StringThe type of the value-added service group.
group_description: StringThe name of the value-added service group.
is_required: boolWhen true, one or more of the value-added services listed must be specified.
value_added_services: Option<Vec<ValueAddedService>>A list of optional value-added services available for purchase with a shipping service offering.
Implementations