pub struct Benefits {
pub included_benefits: Vec<String>,
pub excluded_benefits: Vec<ExcludedBenefit>,
}Expand description
Benefits : Benefits that are included and excluded for each shipping offer. Benefits represents services provided by Amazon (eg. CLAIMS_PROTECTED, etc.) when sellers purchase shipping through Amazon. Benefit details will be made available for any shipment placed on or after January 1st 2024 00:00 UTC.
Fields
included_benefits: Vec<String>A list of included benefits.
excluded_benefits: Vec<ExcludedBenefit>A list of excluded benefit. Refer to the ExcludeBenefit object for further documentation
Implementations
Sourceimpl Benefits
impl Benefits
Sourcepub fn new(
included_benefits: Vec<String>,
excluded_benefits: Vec<ExcludedBenefit>,
) -> Benefits
pub fn new( included_benefits: Vec<String>, excluded_benefits: Vec<ExcludedBenefit>, ) -> Benefits
Benefits that are included and excluded for each shipping offer. Benefits represents services provided by Amazon (eg. CLAIMS_PROTECTED, etc.) when sellers purchase shipping through Amazon. Benefit details will be made available for any shipment placed on or after January 1st 2024 00:00 UTC.