pub enum ClaimReason {
LostInTransit,
DamagedInTransit,
DeliveredNotReceived,
ItemMissingSwitcheroo,
CodAbuse,
}Expand description
ClaimReason : The reason for which shipper is filing the claim for a particular shipment. The reason for which shipper is filing the claim for a particular shipment.
Variants