pub struct ExcludedBenefit {
pub benefit: String,
pub reason_codes: Option<Vec<String>>,
}Expand description
ExcludedBenefit : Object representing a benefit that is excluded for a shipping offer or rate.
Fields
benefit: Stringbenefit
reason_codes: Option<Vec<String>>List of reasons (eg. LATE_DELIVERY_RISK, etc.) indicating why a benefit is excluded for a shipping offer.
Implementations
Sourceimpl ExcludedBenefit
impl ExcludedBenefit
Sourcepub fn new(benefit: String) -> ExcludedBenefit
pub fn new(benefit: String) -> ExcludedBenefit
Object representing a benefit that is excluded for a shipping offer or rate.