GetRatesRequest

Struct GetRatesRequest 

pub struct GetRatesRequest {
Show 13 fields pub ship_to: Option<Box<Address>>, pub ship_from: Box<Address>, pub return_to: Option<Box<Address>>, pub ship_date: Option<String>, pub shipper_instruction: Option<Box<ShipperInstruction>>, pub packages: Vec<Package>, pub value_added_services: Option<Box<ValueAddedServiceDetails>>, pub tax_details: Option<Vec<TaxDetail>>, pub channel_details: Box<ChannelDetails>, pub client_reference_details: Option<Vec<ClientReferenceDetail>>, pub shipment_type: Option<ShipmentType>, pub destination_access_point_details: Option<Box<AccessPointDetails>>, pub carrier_accounts: Option<Vec<CarrierAccount>>,
}
GetRatesRequest : The request schema for the getRates operation. When the channelType is Amazon, the shipTo address is not required and will be ignored.

Fields

ship_to: Option<Box<Address>>ship_from: Box<Address>return_to: Option<Box<Address>>ship_date: Option<String>

The ship date and time (the requested pickup). This defaults to the current date and time.

shipper_instruction: Option<Box<ShipperInstruction>>packages: Vec<Package>

A list of packages to be shipped through a shipping service offering.

value_added_services: Option<Box<ValueAddedServiceDetails>>tax_details: Option<Vec<TaxDetail>>

A list of tax detail information.

channel_details: Box<ChannelDetails>client_reference_details: Option<Vec<ClientReferenceDetail>>

Object to pass additional information about the MCI Integrator shipperType: List of ClientReferenceDetail

shipment_type: Option<ShipmentType>destination_access_point_details: Option<Box<AccessPointDetails>>carrier_accounts: Option<Vec<CarrierAccount>>

A list of CarrierAccounts

Implementations

Source

impl GetRatesRequest

pub fn new( ship_from: Address, packages: Vec<Package>, channel_details: ChannelDetails, ) -> GetRatesRequest

The request schema for the getRates operation. When the channelType is Amazon, the shipTo address is not required and will be ignored.