pub struct GoodsOwner {
pub merchant_id: String,
}Expand description
GoodsOwner : The seller owning the goods before handing them over to the carrier
Fields
merchant_id: Stringmerchant Id of provided merchant
Implementations
Sourceimpl GoodsOwner
impl GoodsOwner
Sourcepub fn new(merchant_id: String) -> GoodsOwner
pub fn new(merchant_id: String) -> GoodsOwner
The seller owning the goods before handing them over to the carrier