pub struct Location {
pub state_or_region: Option<String>,
pub city: Option<String>,
pub country_code: Option<String>,
pub postal_code: Option<String>,
}Expand description
Location : The location where the person, business or institution is located.
Fields
state_or_region: Option<String>The state, county or region where the person, business or institution is located.
city: Option<String>The city or town where the person, business or institution is located.
country_code: Option<String>The two digit country code. Follows ISO 3166-1 alpha-2 format.
postal_code: Option<String>The postal code of that address. It contains a series of letters or digits or both, sometimes including spaces or punctuation.
Implementations