PurchaseShipmentRequest

Struct PurchaseShipmentRequest 

pub struct PurchaseShipmentRequest {
    pub request_token: String,
    pub rate_id: String,
    pub requested_document_specification: Box<RequestedDocumentSpecification>,
    pub requested_value_added_services: Option<Vec<RequestedValueAddedService>>,
    pub additional_inputs: Option<HashMap<String, Value>>,
}
PurchaseShipmentRequest : The request schema for the purchaseShipment operation.

Fields

request_token: String

A unique token generated to identify a getRates operation.

rate_id: String

An identifier for the rate (shipment offering) provided by a shipping service provider.

requested_document_specification: Box<RequestedDocumentSpecification>requested_value_added_services: Option<Vec<RequestedValueAddedService>>

The value-added services to be added to a shipping service purchase.

additional_inputs: Option<HashMap<String, Value>>

The additional inputs required to purchase a shipping offering, in JSON format. The JSON provided here must adhere to the JSON schema that is returned in the response to the getAdditionalInputs operation. Additional inputs are only required when indicated by the requiresAdditionalInputs property in the response to the getRates operation.

Implementations

Source

impl PurchaseShipmentRequest

pub fn new( request_token: String, rate_id: String, requested_document_specification: RequestedDocumentSpecification, ) -> PurchaseShipmentRequest

The request schema for the purchaseShipment operation.