pub struct GetSolicitationActionResponse {
pub _links: Option<Box<GetSolicitationActionResponseLinks>>,
pub _embedded: Option<Box<GetSolicitationActionResponseEmbedded>>,
pub payload: Option<Box<SolicitationsAction>>,
pub errors: Option<Vec<Error>>,
}Expand description
GetSolicitationActionResponse : Describes a solicitation action that can be taken for an order. Provides a JSON Hypertext Application Language (HAL) link to the JSON schema document that describes the expected input.
Fields
_links: Option<Box<GetSolicitationActionResponseLinks>>_embedded: Option<Box<GetSolicitationActionResponseEmbedded>>payload: Option<Box<SolicitationsAction>>errors: Option<Vec<Error>>A list of error responses returned when a request is unsuccessful.
Implementations
Sourceimpl GetSolicitationActionResponse
impl GetSolicitationActionResponse
Sourcepub fn new() -> GetSolicitationActionResponse
pub fn new() -> GetSolicitationActionResponse
Describes a solicitation action that can be taken for an order. Provides a JSON Hypertext Application Language (HAL) link to the JSON schema document that describes the expected input.