LabelData

pub struct LabelData {
    pub package_identifier: Option<String>,
    pub tracking_number: Option<String>,
    pub ship_method: Option<String>,
    pub ship_method_name: Option<String>,
    pub content: String,
}
LabelData : Details of the shipment label.

Fields

package_identifier: Option<String>

Identifier for the package. The first package will be 001, the second 002, and so on. This number is used as a reference to refer to this package from the pallet level.

tracking_number: Option<String>

Package tracking identifier from the shipping carrier.

ship_method: Option<String>

Ship method to be used for shipping the order. Amazon defines Ship Method Codes indicating shipping carrier and shipment service level. Ship Method Codes are case and format sensitive. The same ship method code should returned on the shipment confirmation. Note that the Ship Method Codes are vendor specific and will be provided to each vendor during the implementation.

ship_method_name: Option<String>

Shipping method name for internal reference.

content: String

This field will contain the Base64encoded string of the shipment label content.

Implementations

Source

impl LabelData

pub fn new(content: String) -> LabelData

Details of the shipment label.