pub struct Money {
pub currency_code: Option<String>,
pub amount: Option<String>,
pub unit_of_measure: Option<UnitOfMeasure>,
}Expand description
Money : An amount of money. Includes the currency code and an optional unit of measure for items priced by weight.
Fields
currency_code: Option<String>Three digit currency code in ISO 4217 format. String of length 3.
amount: Option<String>A decimal number with no loss of precision. Useful when precision loss is unacceptable, as with currencies. Follows RFC7159 for number representation.
Pattern : ^-?(0|([1-9]\\d*))(\\.\\d+)?([eE][+-]?\\d+)?$.
unit_of_measure: Option<UnitOfMeasure>The unit of measure for prices of items sold by weight. If this field is absent, the item is sold by eaches.
Implementations