Module order

Module order 

Structs

Order
Order : Represents an order placed by Amazon, including the purchase order number, current state, and order details.

Enums

PurchaseOrderState
This field will contain the current state of the purchase order.