OrderItemAcknowledgement

Struct OrderItemAcknowledgement 

pub struct OrderItemAcknowledgement {
    pub acknowledgement_code: AcknowledgementCode,
    pub acknowledged_quantity: Box<ItemQuantity>,
    pub scheduled_ship_date: Option<String>,
    pub scheduled_delivery_date: Option<String>,
    pub rejection_reason: Option<RejectionReason>,
}
OrderItemAcknowledgement : Represents the acknowledgement details for an individual order item, including the acknowledgement code, acknowledged quantity, scheduled ship and delivery dates, and rejection reason (if applicable).

Fields

acknowledgement_code: AcknowledgementCode

This indicates the acknowledgement code.

acknowledged_quantity: Box<ItemQuantity>scheduled_ship_date: Option<String>

Estimated ship date per line item. Must be in ISO-8601 date/time format.

scheduled_delivery_date: Option<String>

Estimated delivery date per line item. Must be in ISO-8601 date/time format.

rejection_reason: Option<RejectionReason>

Indicates the reason for rejection.

Implementations

Source

impl OrderItemAcknowledgement

pub fn new( acknowledgement_code: AcknowledgementCode, acknowledged_quantity: ItemQuantity, ) -> OrderItemAcknowledgement

Represents the acknowledgement details for an individual order item, including the acknowledgement code, acknowledged quantity, scheduled ship and delivery dates, and rejection reason (if applicable).