pub struct ItemQuantity {
pub amount: i32,
pub unit_of_measure: UnitOfMeasure,
pub unit_size: Option<i32>,
pub total_weight: Option<Box<TotalWeight>>,
}Expand description
ItemQuantity : Details of item quantity.
Fields
amount: i32Amount of units shipped for a specific item at a shipment level. If the item is present only in certain cartons or pallets within the shipment, please provide this at the appropriate carton or pallet level.
unit_of_measure: UnitOfMeasureUnit of measure for the shipped quantity.
unit_size: Option<i32>The case size, in the event that we ordered using cases. Otherwise, 1.
total_weight: Option<Box<TotalWeight>>Implementations
Sourceimpl ItemQuantity
impl ItemQuantity
Sourcepub fn new(amount: i32, unit_of_measure: UnitOfMeasure) -> ItemQuantity
pub fn new(amount: i32, unit_of_measure: UnitOfMeasure) -> ItemQuantity
Details of item quantity.