Shipment

Struct Shipment 

pub struct Shipment {
Show 20 fields pub vendor_shipment_identifier: String, pub transaction_type: TransactionType, pub buyer_reference_number: Option<String>, pub transaction_date: String, pub current_shipment_status: Option<CurrentShipmentStatus>, pub currentshipment_status_date: Option<String>, pub shipment_status_details: Option<Vec<ShipmentStatusDetails>>, pub shipment_create_date: Option<String>, pub shipment_confirm_date: Option<String>, pub package_label_create_date: Option<String>, pub shipment_freight_term: Option<ShipmentFreightTerm>, pub selling_party: Box<PartyIdentification>, pub ship_from_party: Box<PartyIdentification>, pub ship_to_party: Box<PartyIdentification>, pub shipment_measurements: Option<Box<TransportShipmentMeasurements>>, pub collect_freight_pickup_details: Option<Box<CollectFreightPickupDetails>>, pub purchase_orders: Option<Vec<PurchaseOrders>>, pub import_details: Option<Box<ImportDetails>>, pub containers: Option<Vec<Containers>>, pub transportation_details: Option<Box<TransportationDetails>>,
}
Shipment : A list of one or more shipments with respective details.

Fields

vendor_shipment_identifier: String

Unique Transportation ID created by Vendor (Should not be used over the last 365 days).

transaction_type: TransactionType

Indicates the type of transportation request (for example, New or Cancel). Each transactionType has a unique set of operations and there are corresponding details to be populated for each operation.

buyer_reference_number: Option<String>

The buyer Reference Number is a unique identifier generated by buyer for all Collect/WePay shipments when you submit a transportation request. This field is mandatory for Collect/WePay shipments.

transaction_date: String

Date on which the transportation request was submitted.

current_shipment_status: Option<CurrentShipmentStatus>

Indicates the current shipment status.

currentshipment_status_date: Option<String>

Date and time when the last status was updated.

shipment_status_details: Option<Vec<ShipmentStatusDetails>>

Indicates the list of current shipment status details and when the last update was received from carrier this is available on shipment Details response.

shipment_create_date: Option<String>

The date and time of the shipment request created by vendor.

shipment_confirm_date: Option<String>

The date and time of the departure of the shipment from the vendor’s location. Vendors are requested to send ASNs within 30 minutes of departure from their warehouse/distribution center or at least 6 hours prior to the appointment time at the Buyer destination warehouse, whichever is sooner. Shipped date mentioned in the shipment confirmation should not be in the future.

package_label_create_date: Option<String>

The date and time of the package label created for the shipment by buyer.

shipment_freight_term: Option<ShipmentFreightTerm>

Specifies if payment is Collect (WePay) or Prepaid (TheyPay). Required.

selling_party: Box<PartyIdentification>ship_from_party: Box<PartyIdentification>ship_to_party: Box<PartyIdentification>shipment_measurements: Option<Box<TransportShipmentMeasurements>>collect_freight_pickup_details: Option<Box<CollectFreightPickupDetails>>purchase_orders: Option<Vec<PurchaseOrders>>

Indicates the purchase orders involved for the transportation request. This group is an array create 1 for each PO and list their corresponding items. This information is used for deciding the route,truck allocation and storage efficiently. This is a mandatory information for Buyer performing transportation from vendor warehouse (WePay/Collect)

import_details: Option<Box<ImportDetails>>containers: Option<Vec<Containers>>

A list of the items in this transportation and their associated inner container details. If any of the item detail fields are common at a carton or a pallet level, provide them at the corresponding carton or pallet level.

transportation_details: Option<Box<TransportationDetails>>

Implementations

Source

impl Shipment

pub fn new( vendor_shipment_identifier: String, transaction_type: TransactionType, transaction_date: String, selling_party: PartyIdentification, ship_from_party: PartyIdentification, ship_to_party: PartyIdentification, ) -> Shipment

A list of one or more shipments with respective details.