pub struct TotalWeight {
pub unit_of_measure: UnitOfMeasure,
pub amount: String,
}Expand description
TotalWeight : The total weight of units that are sold by weight in a shipment.
Fields
unit_of_measure: UnitOfMeasureThe unit of measure for the weight of items that are ordered by cases and support pricing by weight.
amount: StringA decimal number with no loss of precision. Useful when precision loss is unacceptable, as with currencies. Follows RFC7159 for number representation.
Pattern : ^-?(0|([1-9]\\d*))(\\.\\d+)?([eE][+-]?\\d+)?$.
Implementations
Sourceimpl TotalWeight
impl TotalWeight
Sourcepub fn new(unit_of_measure: UnitOfMeasure, amount: String) -> TotalWeight
pub fn new(unit_of_measure: UnitOfMeasure, amount: String) -> TotalWeight
The total weight of units that are sold by weight in a shipment.