Enums
- GetBrowse
Node Return Topics Error - struct for typed errors of method
get_browse_node_return_topics - GetBrowse
Node Return Trends Error - struct for typed errors of method
get_browse_node_return_trends - GetBrowse
Node Review Topics Error - struct for typed errors of method
get_browse_node_review_topics - GetBrowse
Node Review Trends Error - struct for typed errors of method
get_browse_node_review_trends - GetItem
Browse Node Error - struct for typed errors of method
get_item_browse_node - GetItem
Review Topics Error - struct for typed errors of method
get_item_review_topics - GetItem
Review Trends Error - struct for typed errors of method
get_item_review_trends
Functions
- get_
browse_ node_ return_ topics - Retrieve the topics that customers mention when they return items in a browse node.
- get_
browse_ node_ return_ trends - Retrieve the trends of topics that customers mention when they return items in a browse node.
- get_
browse_ node_ review_ topics - Retrieve a browse node’s ten most positive and ten most negative review topics.
- get_
browse_ node_ review_ trends - Retrieve the positive and negative review trends of items in a browse node for the past six months.
- get_
item_ browse_ node - This API returns the associated browse node of the requested ASIN. A browse node is a location in a browse tree that is used for navigation, product classification, and website content on the Amazon retail website.
- get_
item_ review_ topics - Retrieve an item’s ten most positive and ten most negative review topics.
- get_
item_ review_ trends - Retrieve an item’s positive and negative review trends for the past six months.