pub async fn get_item_browse_node(
configuration: &Configuration,
asin: &str,
marketplace_id: &str,
) -> Result<BrowseNodeResponse, Error<GetItemBrowseNodeError>>Expand description
This API returns the associated browse node of the requested ASIN. A browse node is a location in a browse tree that is used for navigation, product classification, and website content on the Amazon retail website.