Function create_inventory_item

pub async fn create_inventory_item(
    configuration: &Configuration,
    create_inventory_item_request_body: CreateInventoryItemRequest,
) -> Result<CreateInventoryItemResponse, Error<CreateInventoryItemError>>
Requests that Amazon create product-details in the Sandbox Inventory in the sandbox environment. This is a sandbox-only operation and must be directed to a sandbox endpoint. Refer to Selling Partner API sandbox for more information.