Enums
- Create
Transaction Error - struct for typed errors of method
create_transaction - GetTransaction
Error - struct for typed errors of method
get_transaction - List
Account Transactions Error - struct for typed errors of method
list_account_transactions
Functions
- create_
transaction - Create a transaction request from a Seller Wallet account to another customer-provided account.
- get_
transaction - Returns a transaction
- list_
account_ transactions - Retrieve a list of transactions for a given Seller Wallet bank account.