amazon_
spapi
0.1.1
Module transfer_
preview_
api
Module Items
Enums
Functions
In amazon_
spapi::
apis
amazon_spapi
::
apis
Module
transfer_preview_api
Enums

GetTransfer
Preview
Error
struct for typed errors of method
get_transfer_preview
Functions

get_
transfer_
preview
Returns list of potential fees on a transaction based on the source and destination country currency code