pub struct FeatureSettings {
pub feature_name: Option<String>,
pub feature_fulfillment_policy: Option<FeatureFulfillmentPolicy>,
}Expand description
FeatureSettings : FeatureSettings allows users to apply fulfillment features to an order. To block an order from being shipped using Amazon Logistics (AMZL) and an AMZL tracking number, use featureName as BLOCK_AMZL and featureFulfillmentPolicy as Required. Blocking AMZL will incur an additional fee surcharge on your MCF orders and increase the risk of some of your orders being unfulfilled or delivered late if there are no alternative carriers available. Using BLOCK_AMZL in an order request will take precedence over your Seller Central account setting. To ship in non-Amazon branded packaging (blank boxes), use featureName BLANK_BOX.
Fields
feature_name: Option<String>The name of the feature.
feature_fulfillment_policy: Option<FeatureFulfillmentPolicy>Specifies the policy to use when fulfilling an order.
Implementations
Sourceimpl FeatureSettings
impl FeatureSettings
Sourcepub fn new() -> FeatureSettings
pub fn new() -> FeatureSettings
FeatureSettings allows users to apply fulfillment features to an order. To block an order from being shipped using Amazon Logistics (AMZL) and an AMZL tracking number, use featureName as BLOCK_AMZL and featureFulfillmentPolicy as Required. Blocking AMZL will incur an additional fee surcharge on your MCF orders and increase the risk of some of your orders being unfulfilled or delivered late if there are no alternative carriers available. Using BLOCK_AMZL in an order request will take precedence over your Seller Central account setting. To ship in non-Amazon branded packaging (blank boxes), use featureName BLANK_BOX.