amazon_
spapi
1.0.0
Module http_
method
Module Items
Enums
In amazon_
spapi::
models::
product_
pricing_
v0
amazon_spapi
::
models
::
product_pricing_v0
Module
http_method
Enums

Http
Method
HttpMethod : The HTTP method associated with the individual APIs being called as part of the batch request. The HTTP method associated with the individual APIs being called as part of the batch request.