Business

Struct Business 

pub struct Business {
    pub name: String,
    pub registered_business_address: Box<Address>,
    pub company_registration_number: Option<String>,
    pub company_tax_identification_number: Option<String>,
    pub non_latin_name: Option<String>,
}
Business : Information about the seller’s business. Certain fields may be omitted depending on the seller’s businessType.

Fields

name: String

The registered business name.

registered_business_address: Box<Address>company_registration_number: Option<String>

The seller’s company registration number, if applicable. This field will be absent for individual sellers and sole proprietorships.

company_tax_identification_number: Option<String>

The seller’s company tax identification number, if applicable. This field will be present for certain business types only, such as sole proprietorships.

non_latin_name: Option<String>

The non-Latin script version of the registered business name, if applicable.

Implementations

Source

impl Business

pub fn new(name: String, registered_business_address: Address) -> Business

Information about the seller’s business. Certain fields may be omitted depending on the seller’s businessType.