FixedSlot

Struct FixedSlot 

pub struct FixedSlot {
    pub start_date_time: Option<String>,
    pub scheduled_capacity: Option<i32>,
    pub available_capacity: Option<i32>,
    pub encumbered_capacity: Option<i32>,
    pub reserved_capacity: Option<i32>,
}
FixedSlot : In this slot format each slot only has the requested capacity types. This slot size is as specified by slot duration.

Fields

start_date_time: Option<String>

Start date time of slot in ISO 8601 format with precision of seconds.

scheduled_capacity: Option<i32>

Scheduled capacity corresponding to the slot. This capacity represents the originally allocated capacity as per resource schedule.

available_capacity: Option<i32>

Available capacity corresponding to the slot. This capacity represents the capacity available for allocation to reservations.

encumbered_capacity: Option<i32>

Encumbered capacity corresponding to the slot. This capacity represents the capacity allocated for Amazon Jobs/Appointments/Orders.

reserved_capacity: Option<i32>

Reserved capacity corresponding to the slot. This capacity represents the capacity made unavailable due to events like Breaks/Leaves/Lunch.

Implementations

Source

impl FixedSlot

pub fn new() -> FixedSlot

In this slot format each slot only has the requested capacity types. This slot size is as specified by slot duration.