Module order
amazon_
spapi
2.0.3
Module order
Module Items
Structs
Enums
In amazon_
spapi::
models::
vendor_
orders
amazon_spapi
::
models
::
vendor_orders
Module
order
Structs

Order
Order : Represents an order placed by Amazon, including the purchase order number, current state, and order details.
Enums

Purchase
Order
State
This field will contain the current state of the purchase order.